<?php
/**
 * Playlist section
 *
 * This is the template for the content of playlist section
 *
 * @package Theme Palace
 * @subpackage Music Freak Pro
 * @since Music Freak Pro 1.0.0
 */
if ( ! function_exists( 'music_freak_pro_add_playlist_section' ) ) :
    /**
    * Add playlist section
    *
    *@since Music Freak Pro 1.0.0
    */
    function music_freak_pro_add_playlist_section() {
    	$options = music_freak_pro_get_theme_options();
        // Check if playlist is enabled on frontpage
        $playlist_enable = apply_filters( 'music_freak_pro_section_status', true, 'playlist_section_enable' );

        if ( true !== $playlist_enable ) {
            return false;
        }

        // Render playlist section now.
        music_freak_pro_render_playlist_section();
    }
endif;

if ( ! function_exists( 'music_freak_pro_render_playlist_section' ) ) :
    /**
    * Start playlist section
    *
    * @return string playlist content
    * @since Music Freak Pro 1.0.0
    *
    */
    function music_freak_pro_render_playlist_section() {
        $options = music_freak_pro_get_theme_options();
        $playlist = ! empty( $options['playlist_content'] ) ? $options['playlist_content'] : array();

        if ( empty( $playlist ) )
            return;

        $args = array( 
            'post_type' => 'attachment',
            'post_mime_type' => 'audio', 
            'posts_per_page' => -1,
            'post__in' => $playlist 
            );
        $posts = get_posts( $args ); ?>

        <div id="trending-albums" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                    <?php if ( ! empty( $options['playlist_title'] ) ) : ?>
                        <h2 class="section-title"><?php echo esc_html( $options['playlist_title'] ); ?></h2>
                    <?php endif; 

                    if ( ! empty( $options['playlist_btn_title'] ) && ! empty( $options['playlist_btn_url'] ) ) : ?>
                        <a href="<?php echo esc_url( $options['playlist_btn_url'] ); ?>" class="more-link"><?php echo esc_html( $options['playlist_btn_title'] ); ?></a>
                    <?php endif; ?>
                </div><!-- .section-header -->

                <div class="albums-wrapper clear">
                    <?php $i = 1;
                    foreach ( $posts as $post ) : 
                        $image = get_the_post_thumbnail_url( $post->ID ) ? get_the_post_thumbnail_url( $post->ID ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg'; ?>
                        <article class="<?php echo ( $i == 5 ) ? 'half-width' : ''; ?>" data-tab="tab-<?php echo absint( $post->ID ); ?>">
                            <div class="album-item-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                                    <?php $meta = wp_get_attachment_metadata( $post->ID ); ?>
                                    <span><?php echo esc_html( $meta['length_formatted'] ); ?></span>
                                    <a href="#" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="#"><?php echo esc_html( $post->post_title ); ?></a></h2>
                                    </header>

                                    <div class="entry-meta">
                                        <?php music_freak_pro_posted_on( $post->ID ); ?>
                                    </div><!-- .entry-meta -->
                                </div><!-- .entry-container -->
                            </div><!-- .album-item-wrapper -->
                        </article>
                    <?php $i++; endforeach; ?>


                    <div class="tab-section-content">
                        <?php $i = 1; 
                        foreach ( $posts as $post ) : ?>
                            <div id="tab-<?php echo absint( $post->ID ); ?>" class="tab-content <?php echo ( $i == 1 ) ? 'active' : ''; ?>">
                                <?php $image = get_the_post_thumbnail_url( $post->ID ) ? get_the_post_thumbnail_url( $post->ID, 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-150x150.jpg'; ?>
                                <div class="roll">
                                    <img src="<?php echo esc_url( $image ); ?>" class="music-image">
                                    <span class="music-title"><?php echo esc_html( $post->post_title ); ?></span>
                                </div>
                                <?php echo wp_audio_shortcode( array( 'src' => $post->guid ) ); ?>

                            </div><!-- #tab-01 -->
                        <?php $i++; endforeach; ?>
                    </div><!-- .tab-section-content -->
                </div><!-- .albums-wrapper -->

                <?php if ( ! empty( $options['playlist_btn_title'] ) && ! empty( $options['playlist_btn_url'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['playlist_btn_url'] ); ?>" class="more-link"><?php echo esc_html( $options['playlist_btn_title'] ); ?></a>
                    </div><!-- .read-more -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #trending-albums -->

    <?php wp_reset_postdata();
    }
endif;